import shutil

from models.dt import model_dt
from models.rf import model_rf
from models.vanilla_cnn import model_vanilla_cnn
from models.resnet import model_resnet


def load_model(configuration, size, nbclass):
    """
    Load specified model
    
    Parameters
    ----------
    configuration: array
        Elements from the configuration file
        
    size: array
        Dimensions of the input data
        
    nbclass: integer
        Number of classes

    Returns
    -------
    model: model
        Specified model
    """
    models_dict = {
        "dt": model_dt,
        "rf": model_rf,
        "vanilla_cnn": model_vanilla_cnn,
        "resnet": model_resnet,
    }
    model = models_dict[configuration["model_name"]](configuration, size, nbclass)

    return model
